aboutsummaryrefslogtreecommitdiffstats
path: root/core/object.go
diff options
context:
space:
mode:
authorMáximo Cuadros <mcuadros@gmail.com>2016-05-19 16:44:59 +0200
committerMáximo Cuadros <mcuadros@gmail.com>2016-05-19 16:44:59 +0200
commit25077df01588b54ec097ce3f99db6672c5a59463 (patch)
tree49f7b64f4164d19260ba848c5faca366b75438d1 /core/object.go
parent08f9e7015aad2ca768638b446fb8632f11601899 (diff)
downloadgo-git-25077df01588b54ec097ce3f99db6672c5a59463.tar.gz
documentation
Diffstat (limited to 'core/object.go')
-rw-r--r--core/object.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/object.go b/core/object.go
index 9958570..9dd906b 100644
--- a/core/object.go
+++ b/core/object.go
@@ -7,7 +7,7 @@ import (
)
var (
- ObjectNotFoundErr = errors.New("object not found")
+ ErrObjectNotFound = errors.New("object not found")
// ErrInvalidType is returned when an invalid object type is provided.
ErrInvalidType = errors.New("invalid object type")
)
@@ -138,7 +138,7 @@ func NewObjectLookupIter(storage ObjectStorage, series []Hash) *ObjectLookupIter
// Next returns the next object from the iterator. If the iterator has reached
// the end it will return io.EOF as an error. If the object can't be found in
// the object storage, it will return ObjectNotFoundErr as an error. If the
// object is retreieved successfully error will be nil.
func (iter *ObjectLookupIter) Next() (Object, error) {
if iter.pos >= len(iter.series) {
@@ -138,7 +138,7 @@ func NewObjectLookupIter(storage ObjectStorage, series []Hash) *ObjectLookupIter
// Next returns the next object from the iterator. If the iterator has reached
// the end it will return io.EOF as an error. If the object can't be found in
-// the object storage, it will return ObjectNotFoundErr as an error. If the
+// the object storage, it will return ErrObjectNotFound as an error. If the
// object is retreieved successfully error will be nil.
func (iter *ObjectLookupIter) Next() (Object, error) {